@@ -10,7 +10,6 @@ logger.setLevel(settings.LOG_LEVEL)
 
 
 def set_to_output(address):
-    validate_address(address)
     RPIO.setup(address, RPIO.OUT)
 
 
@@ -20,11 +19,7 @@ def pl_switch(address, value):
     address = int(address)
     validate_address(address)
 
-    if not is_output(address):
-        logger.warning("GPIO%s is not OUTPUT configured, changing it ti OUTPUT" % address)
     set_to_output(address)
-
-
     RPIO.output(address, value == "on")
 
 
