@@ -3,12 +3,6 @@ import RPIO
 from hautomation_gpio import USED_GPIO_LIST
 
 
-def is_input(address):
-    return RPIO.gpio_function(address) == RPIO.IN
-
-
-def is_output(address):
-    return RPIO.gpio_function(address) == RPIO.OUT
 
 
 def validate_address(address):
